@@ -1,8 +1,9 @@
 package Debug::Client;
 use strict;
 use warnings;
+use 5.006;
 
-our $VERSION = '0.04';
+our $VERSION = '0.05';
 
 use IO::Socket;
 
@@ -41,6 +42,7 @@ Debug::Client - client side code for perl debugger
 
   $debugger->set_breakpoint( "file", 23 ); # 	set breakpoint on file, line
 
+  $debugger->get_stack_trace
 
 Other planned methods:
 
@@ -51,7 +53,6 @@ Other planned methods:
   $debugger->remove_watch
   $debugger->remove_breakpoint
 
-  $debugger->get_stack_trace
 
   $debugger->watch_variable   (to make it easy to display values of variables)
 
@@ -107,9 +108,24 @@ sub buffer {
 
 sub step_in   { $_[0]->send_get('s') }
 sub step_over { $_[0]->send_get('n') }
-sub quit      { $_[0]->send_get('q') }
+sub quit      { $_[0]->_send('q')    }
 sub show_line { $_[0]->send_get('.') }
 
+sub get_stack_trace {
+    my ($self) = @_;
+    $self->_send('T');
+    my $buf = $self->_get;
+
+    if (wantarray) {
+        my $prompt = _prompt(\$buf);
+        return($buf, $prompt);
+    } else {
+        return $buf;
+    }
+}
+
+
+
 sub run       { 
     my ($self, $param) = @_;
     if (not defined $param) {
@@ -215,12 +231,24 @@ sub _parse_dumper {
     my ($str) = @_;    
 }
 
+# TODO shall we add a timeout and/or a number to count down the number
+# sysread calls that return 0 before deciding it is really done
 sub _get {
     my ($self) = @_;
 
     #my $remote_host = gethostbyaddr($sock->sockaddr(), AF_INET) || 'remote';
     my $buf = '';
-    $self->{new_sock}->sysread($buf, 1024, length $buf) while $buf !~ /DB<\d+>/;
+    while ($buf !~ /DB<\d+>/) {
+        my $ret = $self->{new_sock}->sysread($buf, 1024, length $buf);
+        if (not defined $ret) {
+            die $!; # TODO better error handling?
+        }
+        logger("---- ret '$ret'\n$buf\n---");
+        if (not $ret) {
+            last;
+        }
+    }
+    logger("_get done");
 
     $self->{buffer} = $buf;
     return $buf;
@@ -280,6 +308,11 @@ sub send_get {
     return $self->get;
 }
 
+sub logger {
+    print "$_[0]\n" if $ENV{DEBUG_LOGGER};
+}
+
+
 =head1 See Also
 
 L<GRID::Machine::remotedebugtut>
