@@ -2,6 +2,9 @@ package t::lib::Debugger;
 use strict;
 use warnings;
 
+use File::Temp qw(tempdir);
+
+
 use Exporter;
 use vars qw(@ISA @EXPORT);
 @ISA = ('Exporter');
@@ -9,22 +12,23 @@ use vars qw(@ISA @EXPORT);
 @EXPORT = qw(start_script start_debugger);
 
 my $host = 'localhost';
-my $port = 12345;
+my $port = 12345 + int rand(1000);
 
 sub start_script {
     my ($file) = @_;
     my $pid = fork();
+    my $dir = tempdir(CLEANUP => 1);
+
     die if not defined $pid;
 
     if (not $pid) {
         local $ENV{PERLDB_OPTS} = "RemotePort=$host:$port";
-        unlink 'out', 'err';
         sleep 1;
-        exec "$^X -d $file > out 2> err";
+        exec "$^X -d $file > $dir/out 2> $dir/err";
         exit 0;
     }
 
-    return $pid;
+    return ($dir, $pid);
 }
 
 sub start_debugger {
